/*
  This is an Arduino version of the LMR Start Here robot.
  The original Picaxe version can be found at:
  http://letsmakerobots.com/start
  This version was written for the Arduino Mega
  by ignoblegnome: http://letsmakerobots.com/user/5293
  
  Version 1.2: Adjustments for Ro-Bot-X Arduino Shield for Building Robots and minor tweaks
  Version 1.1: Added backup function
  Version 1.0: Translation of start here robot code
  
  Adapted by jtk14 for Arduino uno and Adafruit's Motor Shield
*/
#define DEBUG 1 // set to 1 to print to serial monitor, 0 to disable
#include <Servo.h>
#include <AFMotor.h>

Servo headservo;
int sharppin = 0;                
int headservopin = 10;
AF_DCMotor motor(3, MOTOR12_64KHZ);
AF_DCMotor motor1(2, MOTOR12_64KHZ);
int dangerlevel = 200;
int backoff = 300;
int turn = 300;
int servo_turn = 700;

int currDist = 0;
int compDist = 0;

void setup() {
  Serial.begin(9600);
  headservo.attach(headservopin);
  headservo.write(90); // 70 or 90
}

void loop() {
  currDist = analogRead(sharppin);
  if(currDist < dangerlevel) {
    nodanger(); 
  }
  else if(currDist > backoff) {
    backup();
  }
  else {
    whichway(); // if obstacle ahead then decide with way is better
  }
delay(500);
  if(DEBUG){
    Serial.print("Current Distance: ");
    Serial.println(currDist);
  }
}

void nodanger() {
  motor.setSpeed(180);
  motor1.setSpeed(180);
  motor.run(FORWARD);
  motor1.run(FORWARD);
  return;
}  

void whichway() {
  totalhalt();
  
  lturn();
  delay(servo_turn);
  int lDist = analogRead(sharppin);
  totalhalt();

  rturn();
  delay(servo_turn);
  int rDist = analogRead(sharppin);
  totalhalt();

  if(lDist < rDist) {
    body_lturn();
  }
    else {
    body_rturn();
  }
  return;
}  

void totalhalt() {
  motor.run(RELEASE);
  motor1.run(RELEASE);
  headservo.write(90);
  delay(1000);
}  

void backup() {
  motor.setSpeed(160);
  motor1.setSpeed(160);
  motor.run(BACKWARD);
  motor1.run(BACKWARD);
  delay(turn);
}  
void lturn() {
  headservo.write(20);
}  

void rturn() {
  headservo.write(160); // or 120
}  

void body_lturn() {
  motor.setSpeed(255);
  motor1.setSpeed(0);
  motor.run(BACKWARD);
  motor1.run(RELEASE);
  delay(1000);
  totalhalt();
}  

void body_rturn() {
  motor1.setSpeed(255);
  motor.setSpeed(0);
  motor.run(RELEASE);
  motor1.run(BACKWARD);
  delay(1000);
  totalhalt();
}  
